@@ -11,7 +11,7 @@
 
 import json
 import shelve
-import semver
+from semver import VersionInfo
 from os.path import join, abspath
 from tempfile import gettempdir
 from collections import deque
@@ -38,12 +38,7 @@ def isValidSemver(version):
     The format is MAJOR.Minor.PATCH, more with https://semver.org
     """
     if version and isinstance(version, string_types):
-        try:
-            semver.parse(version)
-        except (TypeError, ValueError):
-            return False
-        else:
-            return True
+        return VersionInfo.isvalid(version)
     return False
 
 
@@ -51,12 +46,16 @@ def sortedSemver(versions, sort="ASC"):
     """Semantically sort the list of version Numbers"""
     reverse = True if sort.upper() == "DESC" else False
     if versions and isinstance(versions, (list, tuple)):
+        def compare(ver1, ver2):
+            v1 = VersionInfo.parse(ver1)
+            return v1.compare(ver2)
+
         if PY2:
-            return sorted(versions, cmp=semver.compare, reverse=reverse)
+            return sorted(versions, cmp=compare, reverse=reverse)
         else:
             from functools import cmp_to_key
             return sorted(
-                versions, key=cmp_to_key(semver.compare),
+                versions, key=cmp_to_key(compare),
                 reverse=reverse
             )
     else:
@@ -87,6 +86,14 @@ class BaseStorage(object):
         """
         return getattr(self, "COVERED_INDEX", None) or self.DEFAULT_INDEX
 
+    @index.setter
+    def index(self, _covered_index):
+        """Set the covered index
+
+        .. versionadded:: 3.6.0
+        """
+        self.COVERED_INDEX = _covered_index
+
     def __getitem__(self, key):
         if hasattr(self, "get"):
             return self.get(key)
@@ -256,15 +263,12 @@ class RedisStorage(BaseStorage):
     def __len__(self):
         return self._db.hlen(self.index)
 
-    def __del__(self):
-        if self._db:
-            self._db.connection_pool.disconnect()
-
 
 class MongoStorage(BaseStorage):
     """Use mongodb stand-alone storage
 
-    .. versionadded:: 3.4.0
+    .. deprecated:: 3.6.0
+        The next version removed
     """
 
     def __init__(self, mongo_url=None, mongo_connection=None):
